summaryrefslogtreecommitdiff
path: root/fs/orangefs/pvfs2-cache.c
diff options
context:
space:
mode:
Diffstat (limited to 'fs/orangefs/pvfs2-cache.c')
-rw-r--r--fs/orangefs/pvfs2-cache.c122
1 files changed, 61 insertions, 61 deletions
diff --git a/fs/orangefs/pvfs2-cache.c b/fs/orangefs/pvfs2-cache.c
index f982616..a224831 100644
--- a/fs/orangefs/pvfs2-cache.c
+++ b/fs/orangefs/pvfs2-cache.c
@@ -11,27 +11,27 @@
static __u64 next_tag_value;
static DEFINE_SPINLOCK(next_tag_value_lock);
/* the pvfs2 memory caches */
/* a cache for pvfs2 upcall/downcall operations */
static struct kmem_cache *op_cache;
/* a cache for device (/dev/pvfs2-req) communication */
static struct kmem_cache *dev_req_cache;
-/* a cache for pvfs2_kiocb objects (i.e pvfs2 iocb structures ) */
-static struct kmem_cache *pvfs2_kiocb_cache;
+/* a cache for orangefs_kiocb objects (i.e orangefs iocb structures ) */
+static struct kmem_cache *orangefs_kiocb_cache;
int op_cache_initialize(void)
{
- op_cache = kmem_cache_create("pvfs2_op_cache",
- sizeof(struct pvfs2_kernel_op_s),
+ op_cache = kmem_cache_create("orangefs_op_cache",
+ sizeof(struct orangefs_kernel_op_s),
0,
- PVFS2_CACHE_CREATE_FLAGS,
+ ORANGEFS_CACHE_CREATE_FLAGS,
NULL);
if (!op_cache) {
- gossip_err("Cannot create pvfs2_op_cache\n");
+ gossip_err("Cannot create orangefs_op_cache\n");
return -ENOMEM;
}
@@ -48,72 +48,72 @@ int op_cache_finalize(void)
return 0;
}
-char *get_opname_string(struct pvfs2_kernel_op_s *new_op)
+char *get_opname_string(struct orangefs_kernel_op_s *new_op)
{
if (new_op) {
__s32 type = new_op->upcall.type;
- if (type == PVFS2_VFS_OP_FILE_IO)
+ if (type == ORANGEFS_VFS_OP_FILE_IO)
return "OP_FILE_IO";
- else if (type == PVFS2_VFS_OP_LOOKUP)
+ else if (type == ORANGEFS_VFS_OP_LOOKUP)
return "OP_LOOKUP";
- else if (type == PVFS2_VFS_OP_CREATE)
+ else if (type == ORANGEFS_VFS_OP_CREATE)
return "OP_CREATE";
- else if (type == PVFS2_VFS_OP_GETATTR)
+ else if (type == ORANGEFS_VFS_OP_GETATTR)
return "OP_GETATTR";
- else if (type == PVFS2_VFS_OP_REMOVE)
+ else if (type == ORANGEFS_VFS_OP_REMOVE)
return "OP_REMOVE";
- else if (type == PVFS2_VFS_OP_MKDIR)
+ else if (type == ORANGEFS_VFS_OP_MKDIR)
return "OP_MKDIR";
- else if (type == PVFS2_VFS_OP_READDIR)
+ else if (type == ORANGEFS_VFS_OP_READDIR)
return "OP_READDIR";
- else if (type == PVFS2_VFS_OP_READDIRPLUS)
+ else if (type == ORANGEFS_VFS_OP_READDIRPLUS)
return "OP_READDIRPLUS";
- else if (type == PVFS2_VFS_OP_SETATTR)
+ else if (type == ORANGEFS_VFS_OP_SETATTR)
return "OP_SETATTR";
- else if (type == PVFS2_VFS_OP_SYMLINK)
+ else if (type == ORANGEFS_VFS_OP_SYMLINK)
return "OP_SYMLINK";
- else if (type == PVFS2_VFS_OP_RENAME)
+ else if (type == ORANGEFS_VFS_OP_RENAME)
return "OP_RENAME";
- else if (type == PVFS2_VFS_OP_STATFS)
+ else if (type == ORANGEFS_VFS_OP_STATFS)
return "OP_STATFS";
- else if (type == PVFS2_VFS_OP_TRUNCATE)
+ else if (type == ORANGEFS_VFS_OP_TRUNCATE)
return "OP_TRUNCATE";
- else if (type == PVFS2_VFS_OP_MMAP_RA_FLUSH)
+ else if (type == ORANGEFS_VFS_OP_MMAP_RA_FLUSH)
return "OP_MMAP_RA_FLUSH";
- else if (type == PVFS2_VFS_OP_FS_MOUNT)
+ else if (type == ORANGEFS_VFS_OP_FS_MOUNT)
return "OP_FS_MOUNT";
- else if (type == PVFS2_VFS_OP_FS_UMOUNT)
+ else if (type == ORANGEFS_VFS_OP_FS_UMOUNT)
return "OP_FS_UMOUNT";
- else if (type == PVFS2_VFS_OP_GETXATTR)
+ else if (type == ORANGEFS_VFS_OP_GETXATTR)
return "OP_GETXATTR";
- else if (type == PVFS2_VFS_OP_SETXATTR)
+ else if (type == ORANGEFS_VFS_OP_SETXATTR)
return "OP_SETXATTR";
- else if (type == PVFS2_VFS_OP_LISTXATTR)
+ else if (type == ORANGEFS_VFS_OP_LISTXATTR)
return "OP_LISTXATTR";
- else if (type == PVFS2_VFS_OP_REMOVEXATTR)
+ else if (type == ORANGEFS_VFS_OP_REMOVEXATTR)
return "OP_REMOVEXATTR";
- else if (type == PVFS2_VFS_OP_PARAM)
+ else if (type == ORANGEFS_VFS_OP_PARAM)
return "OP_PARAM";
- else if (type == PVFS2_VFS_OP_PERF_COUNT)
+ else if (type == ORANGEFS_VFS_OP_PERF_COUNT)
return "OP_PERF_COUNT";
- else if (type == PVFS2_VFS_OP_CANCEL)
+ else if (type == ORANGEFS_VFS_OP_CANCEL)
return "OP_CANCEL";
- else if (type == PVFS2_VFS_OP_FSYNC)
+ else if (type == ORANGEFS_VFS_OP_FSYNC)
return "OP_FSYNC";
- else if (type == PVFS2_VFS_OP_FSKEY)
+ else if (type == ORANGEFS_VFS_OP_FSKEY)
return "OP_FSKEY";
}
return "OP_UNKNOWN?";
}
-struct pvfs2_kernel_op_s *op_alloc(__s32 type)
+struct orangefs_kernel_op_s *op_alloc(__s32 type)
{
- struct pvfs2_kernel_op_s *new_op = NULL;
+ struct orangefs_kernel_op_s *new_op = NULL;
- new_op = kmem_cache_alloc(op_cache, PVFS2_CACHE_ALLOC_FLAGS);
+ new_op = kmem_cache_alloc(op_cache, ORANGEFS_CACHE_ALLOC_FLAGS);
if (new_op) {
- memset(new_op, 0, sizeof(struct pvfs2_kernel_op_s));
+ memset(new_op, 0, sizeof(struct orangefs_kernel_op_s));
INIT_LIST_HEAD(&new_op->list);
spin_lock_init(&new_op->lock);
@@ -122,7 +122,7 @@ struct pvfs2_kernel_op_s *op_alloc(__s32 type)
init_waitqueue_head(&new_op->io_completion_waitq);
atomic_set(&new_op->aio_ref_count, 0);
- pvfs2_op_initialize(new_op);
+ orangefs_op_initialize(new_op);
/* initialize the op specific tag and upcall credentials */
spin_lock(&next_tag_value_lock);
@@ -149,15 +149,15 @@ struct pvfs2_kernel_op_s *op_alloc(__s32 type)
return new_op;
}
-void op_release(struct pvfs2_kernel_op_s *pvfs2_op)
+void op_release(struct orangefs_kernel_op_s *orangefs_op)
{
- if (pvfs2_op) {
+ if (orangefs_op) {
gossip_debug(GOSSIP_CACHE_DEBUG,
"Releasing OP (%p: %llu)\n",
- pvfs2_op,
- llu(pvfs2_op->tag));
- pvfs2_op_initialize(pvfs2_op);
- kmem_cache_free(op_cache, pvfs2_op);
+ orangefs_op,
+ llu(orangefs_op->tag));
+ orangefs_op_initialize(orangefs_op);
+ kmem_cache_free(op_cache, orangefs_op);
} else {
gossip_err("NULL pointer in op_release\n");
}
@@ -165,14 +165,14 @@ void op_release(struct pvfs2_kernel_op_s *pvfs2_op)
int dev_req_cache_initialize(void)
{
- dev_req_cache = kmem_cache_create("pvfs2_devreqcache",
+ dev_req_cache = kmem_cache_create("orangefs_devreqcache",
MAX_ALIGNED_DEV_REQ_DOWNSIZE,
0,
- PVFS2_CACHE_CREATE_FLAGS,
+ ORANGEFS_CACHE_CREATE_FLAGS,
NULL);
if (!dev_req_cache) {
- gossip_err("Cannot create pvfs2_dev_req_cache\n");
+ gossip_err("Cannot create orangefs_dev_req_cache\n");
return -ENOMEM;
}
return 0;
@@ -188,7 +188,7 @@ void *dev_req_alloc(void)
{
void *buffer;
- buffer = kmem_cache_alloc(dev_req_cache, PVFS2_CACHE_ALLOC_FLAGS);
+ buffer = kmem_cache_alloc(dev_req_cache, ORANGEFS_CACHE_ALLOC_FLAGS);
if (buffer == NULL)
gossip_err("Failed to allocate from dev_req_cache\n");
else
@@ -206,14 +206,14 @@ void dev_req_release(void *buffer)
int kiocb_cache_initialize(void)
{
- pvfs2_kiocb_cache = kmem_cache_create("pvfs2_kiocbcache",
- sizeof(struct pvfs2_kiocb_s),
+ orangefs_kiocb_cache = kmem_cache_create("orangefs_kiocbcache",
+ sizeof(struct orangefs_kiocb_s),
0,
- PVFS2_CACHE_CREATE_FLAGS,
+ ORANGEFS_CACHE_CREATE_FLAGS,
NULL);
- if (!pvfs2_kiocb_cache) {
- gossip_err("Cannot create pvfs2_kiocb_cache!\n");
+ if (!orangefs_kiocb_cache) {
+ gossip_err("Cannot create orangefs_kiocb_cache!\n");
return -ENOMEM;
}
return 0;
@@ -221,26 +221,26 @@ int kiocb_cache_initialize(void)
int kiocb_cache_finalize(void)
{
- kmem_cache_destroy(pvfs2_kiocb_cache);
+ kmem_cache_destroy(orangefs_kiocb_cache);
return 0;
}
-struct pvfs2_kiocb_s *kiocb_alloc(void)
+struct orangefs_kiocb_s *kiocb_alloc(void)
{
- struct pvfs2_kiocb_s *x = NULL;
+ struct orangefs_kiocb_s *x = NULL;
- x = kmem_cache_alloc(pvfs2_kiocb_cache, PVFS2_CACHE_ALLOC_FLAGS);
+ x = kmem_cache_alloc(orangefs_kiocb_cache, ORANGEFS_CACHE_ALLOC_FLAGS);
if (x == NULL)
gossip_err("kiocb_alloc: kmem_cache_alloc failed!\n");
else
- memset(x, 0, sizeof(struct pvfs2_kiocb_s));
+ memset(x, 0, sizeof(struct orangefs_kiocb_s));
return x;
}
-void kiocb_release(struct pvfs2_kiocb_s *x)
+void kiocb_release(struct orangefs_kiocb_s *x)
{
if (x)
- kmem_cache_free(pvfs2_kiocb_cache, x);
+ kmem_cache_free(orangefs_kiocb_cache, x);
else
gossip_err("kiocb_release: kmem_cache_free NULL pointer!\n");
}
@@ -11,27 +11,27 @@
static __u64 next_tag_value;
static DEFINE_SPINLOCK(next_tag_value_lock);
-/* the pvfs2 memory caches */
+/* the orangefs memory caches */
-/* a cache for pvfs2 upcall/downcall operations */
+/* a cache for orangefs upcall/downcall operations */
static struct kmem_cache *op_cache;
/* a cache for device (/dev/pvfs2-req) communication */